@@ -61,7 +61,7 @@ class MaildirAccount
     guarantee_maildir(dir)
 
     del_count = 0
-    recent_time = Time.now() -- (3 * 24 * 60 * 60) # 3 days
+    recent_time = Time.now() - (3 * 24 * 60 * 60) # 3 days
     Dir[File.join(dir, 'cur', '*')].each do |fn|
       flags = maildir_file_info_flags(fn)
       # don't consider not-seen, flagged, or recent messages
